==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/breves/lang/breves_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/breves?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'breve' => 'خبر',
	'breves' => 'الأخبار',

	// E
	'entree_breve_publiee' => 'هذا الخبر:',
	'entree_texte_breve' => 'مادة الخبر',

	// I
	'icone_breves' => 'الأخبار',
	'icone_ecrire_nouvel_article' => 'الأخبار الموجودة في هذا القسم',
	'icone_modifier_breve' => 'تعديل هذا الخبر',
	'icone_nouvelle_breve' => 'كتابة خبر جديد',
	'info_1_breve' => 'خبر واحد',
	'info_aucun_breve' => 'لا خبر',
	'info_breves' => 'هل يستخدم موقعك نظام الأخبار؟',
	'info_breves_02' => 'الأخبار',
	'info_breves_valider' => 'أخبار قيد التصديق',
	'info_gauche_numero_breve' => 'خبر رقم',
	'info_nb_breves' => '@nb@ خبر',
	'item_breve_proposee' => 'خبر مقترح',
	'item_breve_refusee' => 'خبر مرفوض',
	'item_breve_validee' => 'خبر مصدّق',
	'item_non_utiliser_breves' => 'عدم استخدام الأخبار',
	'item_utiliser_breves' => 'إستخدام الأخبار',

	// L
	'logo_breve' => 'شعار الخبر',

	// T
	'texte_breves' => 'الأخيار هي نصوص قصيرة تسمح
بنشر معلومات سريعة ومقتضبة، إدارة
نشرة أخبار او روزنامة أحداث...',
	'titre_breve_proposee' => 'خبر مقترح',
	'titre_breve_publiee' => 'خبر منشور',
	'titre_breve_refusee' => 'خبر مرفوض',
	'titre_breves' => 'الأخبار',
	'titre_langue_breve' => 'لغة الخبر',
	'titre_nouvelle_breve' => 'خبر جديد',
	'titre_page_breves' => 'الأخبار'
);

?>

==> spip_3.2.7.orig.tar.xz: spip/plugins-dist/breves/lang/breves_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/breves?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'breve' => 'خبر',
	'breves' => 'الأخبار',

	// E
	'entree_breve_publiee' => 'هذا الخبر:',
	'entree_texte_breve' => 'مادة الخبر',

	// I
	'icone_breves' => 'الأخبار',
	'icone_ecrire_nouvel_article' => 'الأخبار الموجودة في هذا القسم',
	'icone_modifier_breve' => 'تعديل هذا الخبر',
	'icone_nouvelle_breve' => 'كتابة خبر جديد',
	'info_1_breve' => 'خبر واحد',
	'info_aucun_breve' => 'لا خبر',
	'info_breves' => 'هل يستخدم موقعك نظام الأخبار؟',
	'info_breves_02' => 'الأخبار',
	'info_breves_valider' => 'أخبار قيد التصديق',
	'info_gauche_numero_breve' => 'خبر رقم',
	'info_nb_breves' => '@nb@ خبر',
	'item_breve_proposee' => 'خبر مقترح',
	'item_breve_refusee' => 'خبر مرفوض',
	'item_breve_validee' => 'خبر مصدّق',
	'item_non_utiliser_breves' => 'عدم استخدام الأخبار',
	'item_utiliser_breves' => 'إستخدام الأخبار',

	// L
	'logo_breve' => 'رمز الخبر',

	// T
	'texte_breves' => 'الأخيار هي نصوص قصيرة تسمح
بنشر معلومات سريعة ومقتضبة، إدارة
نشرة أخبار او روزنامة أحداث...',
	'titre_breve_proposee' => 'خبر مقترح',
	'titre_breve_publiee' => 'خبر منشور',
	'titre_breve_refusee' => 'خبر مرفوض',
	'titre_breves' => 'الأخبار',
	'titre_langue_breve' => 'لغة الخبر',
	'titre_nouvelle_breve' => 'خبر جديد',
	'titre_page_breves' => 'الأخبار'
);
